@@ -49,7 +49,7 @@ EV - perl interface to libev, a high performance full-featured event loop
    };
    
    # MAINLOOP
-   EV::run;                # loop until EV::unloop is called or all watchers stop
+   EV::run;                # loop until EV::break is called or all watchers stop
    EV::run EV::RUN_ONCE;   # block until at least one event could be handled
    EV::run EV::RUN_NOWAIT; # try to handle same events, but do not block
 
@@ -121,7 +121,7 @@ package EV;
 use common::sense;
 
 BEGIN {
-   our $VERSION = '4.18';
+   our $VERSION = 4.22;
    use XSLoader;
    local $^W = 0; # avoid spurious warning
    XSLoader::load "EV", $VERSION;
@@ -298,7 +298,7 @@ or EV::BACKEND_EPOLL).
 =item $active = $loop->run ([$flags])
 
 Begin checking for events and calling callbacks. It returns when a
-callback calls EV::unloop or the flasg are nonzero (in which case the
+callback calls EV::break or the flasg are nonzero (in which case the
 return value is true) or when there are no active watchers which reference
 the loop (keepalive is true), in which case the return value will be
 false. The returnv alue can generally be interpreted as "if true, there is
@@ -616,13 +616,15 @@ clock, the timer will nevertheless run (roughly) the same time.
 
 The C<timer_ns> variant doesn't start (activate) the newly created watcher.
 
-=item $w->set ($after, $repeat)
+=item $w->set ($after, $repeat = 0)
 
 Reconfigures the watcher, see the constructor above for details. Can be called at
 any time.
 
 =item $w->again
 
+=item $w->again ($repeat)
+
 Similar to the C<start> method, but has special semantics for repeating timers:
 
 If the timer is active and non-repeating, it will be stopped.
@@ -639,6 +641,13 @@ operation. You create a timer object with the same value for C<$after> and
 C<$repeat>, and then, in the read/write watcher, run the C<again> method
 on the timeout.
 
+If called with a C<$repeat> argument, then it uses this a timer repeat
+value.
+
+=item $after = $w->remaining
+
+Calculates and returns the remaining time till the timer will fire.
+
 =back
 
 
